@@ -41,7 +41,7 @@ QWidget *checkBoxDelegate::createEditor(QWidget *parent,
         return editor;
     }
     return QItemDelegate::createEditor(parent, option, index);
-    return 0;
+    return nullptr;
 }
 //! [1]
 
@@ -81,7 +81,7 @@ void checkBoxDelegate::setModelData(QWidget *editor, QAbstractItemModel *model,
 //! [4]
 void checkBoxDelegate::updateEditorGeometry(QWidget *editor,
                                             const QStyleOptionViewItem &option,
-                                            const QModelIndex &index) const
+                                            const QModelIndex & /*index*/) const
 {
     printf("updateEditorGeometry\n");
     //	if(index.column()==1)
@@ -96,7 +96,7 @@ void checkBoxDelegate::paint(QPainter *painter,
     printf("paint\n");
     if (index.column() == 1)
     {
-        QVariant value = 0; // index.model()->data(index, Qt::UserRole);
+//        QVariant value = 0; // index.model()->data(index, Qt::UserRole);
                             /* if (!isSupportedType(value.type())) {
                                      QStyleOptionViewItem myOption = option;
                                      myOption.state &= ~QStyle::State_Enabled;
