@@ -20,14 +20,14 @@
  * MA 02110-1301, USA.
  */
 
-#include <stdio.h>
+#include <cstdio>
 #include <netdb.h>
 #include <netinet/in.h>
 
 #include "details.h"
 //#include "proc.h" // static flag
 #include "qps.h" // static flag
-Details::Details(Procinfo *p, Proc *proc) : QWidget(0)
+Details::Details(Procinfo *p, Proc *proc) : QWidget(nullptr)
 {
     pi = p;
     pi->detail = this;
@@ -75,16 +75,16 @@ Details::~Details()
         pi->detail = nullptr;
 }
 
-void Details::set_procinfo(Procinfo *p)
+void Details::set_procinfo(Procinfo * /*p*/)
 {
     //	printf("p=%x, pi=%x\n",p,pi);
 }
 void Details::refresh()
 {
     printf("Details::refresh()\n");
-    QWidget *w = NULL; // tbar->currentPage ();
+    QWidget *w = nullptr; // tbar->currentPage ();
     // QWidget *w= tbar->currentPage ();
-    if (w != NULL)
+    if (w != nullptr)
     {
         /// printf("refresh()\n");
         ((SimpleTable *)w)->refresh();
@@ -94,7 +94,7 @@ void Details::refresh()
 void Details::process_gone()
 {
     ///	printf("process_gone() *******************************\n");
-    pi = 0;
+    pi = nullptr;
     // for now, we just close the window. Another possibility would be
     // to leave it with a "process terminated" note.
     close();
@@ -140,7 +140,7 @@ QString SimpleTable::tipText(int col) { return fields[col].tooltip; }
 // declaration of static members
 bool Sockets::have_services = false;
 QHash<int, char *> Sockets::servdict;
-Lookup *Sockets::lookup = 0;
+Lookup *Sockets::lookup = nullptr;
 
 TableField *Sockets::fields()
 {
@@ -269,7 +269,7 @@ QString Sockets::ipAddr(unsigned addr)
         s = lookup->hostname(addr);
         if (s.isNull())
         {
-            s.sprintf("(%d.%d.%d.%d)", (a >> 24) & 0xff, (a >> 16) & 0xff,
+            s = QString::asprintf("(%d.%d.%d.%d)", (a >> 24) & 0xff, (a >> 16) & 0xff,
                       (a >> 8) & 0xff, a & 0xff);
         }
     }
@@ -278,7 +278,7 @@ QString Sockets::ipAddr(unsigned addr)
         if (a == 0)
             s = "*";
         else
-            s.sprintf("%d.%d.%d.%d", (a >> 24) & 0xff, (a >> 16) & 0xff,
+            s = QString::asprintf("%d.%d.%d.%d", (a >> 24) & 0xff, (a >> 16) & 0xff,
                       (a >> 8) & 0xff, a & 0xff);
     }
     return s;
@@ -325,10 +325,10 @@ void Sockets::config_change()
 }
 
 // slot: called when a host name has been looked up
-void Sockets::update_hostname(unsigned addr)
+void Sockets::update_hostname(unsigned /*addr*/)
 {
     // if(widthChanged(REMOTEADDR) || widthChanged(LOCALADDR)) {
-    if (1)
+    if (true)
     {
         ////	updateTableSize();
         ///	repaintAll();
@@ -345,7 +345,7 @@ void Sockets::update_hostname(unsigned addr)
         int rows = p->sock_inodes.size();
         for (int i = 0; i < rows; i++)
         {
-            int inode = p->sock_inodes[i]->inode;
+            /// int inode = p->sock_inodes[i]->inode;
             /// Sockinfo *si = Procinfo::socks[inode];
             /// if(si->local_addr == addr) updateCell(i, LOCALADDR);
             /// if(si->rem_addr == addr)	updateCell(i,
@@ -362,7 +362,7 @@ const char *Sockets::servname(unsigned port)
         // fill servdict from /etc/services (just try once)
         setservent(1);
         struct servent *s;
-        while ((s = getservent()) != 0)
+        while ((s = getservent()) != nullptr)
         {
             unsigned short hport = ntohs((unsigned short)s->s_port);
             if (!servdict.value(hport, NULL))
@@ -428,7 +428,7 @@ Maps::Maps(QWidget *parent) : SimpleTable(parent, MAPSFIELDS, fields() )
     }
     else
     {
-        int ps = f.pointSize();
+        /// int ps = f.pointSize();
         /// setBodyFont(QFont("Courier", ps ? ps : 10));
     }
 
@@ -479,7 +479,7 @@ QString Maps::text(int row, int col)
         s = buf;
         break;
     case DEVICE:
-        s.sprintf("%2u,%2u", mi->major, mi->minor);
+        s = QString::asprintf("%2u,%2u", mi->major, mi->minor);
         break;
     case INODE:
         s.setNum(mi->inode);
@@ -564,7 +564,7 @@ void Files::refresh_window()
 QString Files::text(int row, int col)
 {
     Procinfo *p = procinfo(); // alot!!
-    if (p == 0)
+    if (p == nullptr)
         return "zero";
     //	printf("p=%x px=%x\n",p,px);
     if (p->fd_files.size() == 0)
