@@ -35,6 +35,7 @@
 #include <QStyleOption>
 #include <QPalette>
 #include <QApplication>
+#include <Qt>
 
 FloatingHead::FloatingHead(QWidget *parent) : QWidget(parent) {}
 
@@ -43,7 +44,7 @@ void FloatingHead::setTitleAndSize(QString str, int w, int h)
     title = str;
     resize(w, h);
 }
-void FloatingHead::paintEvent(QPaintEvent *event)
+void FloatingHead::paintEvent(QPaintEvent * /*event*/)
 {
     QPainter p(this);
     QStyleOptionHeader opt;
@@ -222,7 +223,7 @@ TableBody::TableBody(HeadedTable *parent) : QtTableView(parent), htable(parent)
 }
 
 // virtual from QtTableView
-void TableBody::scrollTrigger(int rx, int ry)
+void TableBody::scrollTrigger(int /*rx*/, int ry)
 {
     if (ry == 0)
         return;
@@ -257,7 +258,7 @@ bool TableBody::isCellChanged(int row, int col)
     // int left = leftCell(), top = topCell();
     CellAttribute *attr = tablecache.value(row - topCell(), col - leftCell());
 
-    if (attr == NULL) // never NULL
+    if (attr == nullptr) // never NULL
     {
         return true;
     }
@@ -348,8 +349,6 @@ bool TableHead::isCellChanged(int row, int col)
     return result;
 }
 
-#include <Qt>
-
 // DRAFT CODE !!  BOTTLENECK !!!
 // Description : draw a cell of table
 // 		1. draw the background of a cell
@@ -518,7 +517,7 @@ void TableBody::showRange(int from, int to)
 int TableBody::cellWidth(int col) const { return htable->max_widths[col]; }
 
 // **** fix !!
-void TableBody::updateRow(int row)
+void TableBody::updateRow(int /*row*/)
 {
     // ??
     // for(int col = 0; col < htable->ncols; col++)
@@ -739,7 +738,7 @@ void TableBody::dragSelectTo(int row)
 }
 
 // HeadedTable: the actually useable class
-HeadedTable::HeadedTable(QWidget *parent, int opts) : QWidget(parent)
+HeadedTable::HeadedTable(QWidget *parent, int /*opts*/) : QWidget(parent)
 {
     // meaningless?
     options = HTBL_ROW_CONTEXT_MENU | HTBL_ROW_SELECTION |
@@ -817,7 +816,7 @@ void HeadedTable::fontChange()
 }
 
 // DRAFT  virtual !
-void HeadedTable::moveCol(int col, int place)
+void HeadedTable::moveCol(int /*col*/, int /*place*/)
 {
     // go to void Procview::moveColumn(int col, int place)
 }
@@ -915,7 +914,7 @@ void HeadedTable::selectAll()
 
 // default implementation returns a null string (no tip d)
 QString HeadedTable::tipText(int) { return ""; }
-char *HeadedTable::total_selectedRow(int col) { return 0; }
+char *HeadedTable::total_selectedRow(int /*col*/) { return nullptr; }
 
 // should be called before setNumCols()
 void HeadedTable::setNumRows(int rows)
@@ -1119,11 +1118,11 @@ void HeadedTable::repaint_changed()
     body->repaintChanged();
 }
 
-void HeadedTable::hideEvent(QHideEvent *event) {}
+void HeadedTable::hideEvent(QHideEvent * /*event*/) {}
 
-void HeadedTable::paintEvent(QPaintEvent *e)
+void HeadedTable::paintEvent(QPaintEvent * /*e*/)
 {
-    static int c = 0;
+    // static int c = 0;
     //	printf("HeadedTable paintEvent %d\n",c++); //works ?
     //	QWidget::paintEvent(e);
     // body->clearCache();
