@@ -20,9 +20,9 @@
  * MA 02110-1301, USA.
  */
 
-#include <stdio.h>
+#include <cstdio>
 #include <sys/types.h>
-#include <time.h>
+#include <ctime>
 
 #include "infobar.h"
 #include "proc.h"
@@ -41,7 +41,7 @@ float cpu_idle = 0;
 float cpu_used = 0;
 
 QMenu *m_popup;
-subcpuRack *cpubar = 0; // DEL extra CPU_window
+subcpuRack *cpubar = nullptr; // DEL extra CPU_window
 
 // ============================
 gwidget *x_cpu;
@@ -61,7 +61,7 @@ class VCursor
 VCursor vcursor;
 
 // DEL
-void Infobar::hideEvent(QHideEvent *event)
+void Infobar::hideEvent(QHideEvent * /*event*/)
 {
     // printf("Infobar::hideEvent()\n");
     // cpubar->hide();
@@ -92,8 +92,6 @@ char rotate_char = '|';
 // DEL
 void Infobar::refresh()
 {
-    QString s;
-
     if (rotate_str[++rotate_idx] == 0)
         rotate_idx = 0;
     rotate_char = rotate_str[rotate_idx];
@@ -365,14 +363,13 @@ class w_cpu : public gwidget
     long total, user, system, idle, nice, wait;
 
   public:
-    virtual void draw(QPainter *p)
+    void draw(QPainter *p) override
     {
         x = 0;
         char buff[32];
         int cpu_id;
         int cpu_n;
         int gheight = 10;
-        int w;
         int mw;
 
         user = 0, system = 0, idle = 0, nice = 0, wait = 0;
@@ -443,7 +440,7 @@ class w_cpu : public gwidget
                 if (c >= 2)
                     mw -= 6;
 
-                if (0)
+                if (false)
                 {
                     printf("cpuid %d , user %d , %d \n", 1,
                            procview->cpu_times(1, Proc::CPUTIME_USER),
@@ -451,13 +448,13 @@ class w_cpu : public gwidget
                 }
 
 #ifdef LINUX
-                int z = drawSPECTRUM2(p, mw, gheight + 1 + r * (gheight - 1),
+                (void) drawSPECTRUM2(p, mw, gheight + 1 + r * (gheight - 1),
                                       buff, total, user, system, nice,
                                       gheight - 2, bar_w);
 #endif
 
 #ifdef SOLARIS
-                int z = drawSPECTRUM2(p, mw, gheight + 1 + r * (gheight - 1),
+                (void) drawSPECTRUM2(p, mw, gheight + 1 + r * (gheight - 1),
                                       buff, total, user, system, wait,
                                       gheight - 2, bar_w);
 // drawSPECTRUM(p,0,cpu_id*10,buff,total,user,system,wait);
@@ -469,9 +466,8 @@ class w_cpu : public gwidget
         height = gheight * 1;
     }
 
-    virtual char *info()
+    char *info() override
     {
-        char str[80];
         float f_user, f_nice, f_system, f_wait;
 
         f_user = (float)user / total * 100;
@@ -497,7 +493,7 @@ class w_mem : public gwidget
     int used;
 
   public:
-    virtual void draw(QPainter *p)
+    void draw(QPainter *p) override
     {
         height = pf_char_height() + 4;
         x = x_cpu->xpluswidth() + 10;
@@ -513,7 +509,7 @@ class w_mem : public gwidget
         width = drawSPECTRUM(p, x, 0, "MEM", procview->mem_total, used);
 #endif
     }
-    virtual char *info()
+    char *info() override
     {
         char str[80];
 
@@ -547,14 +543,14 @@ class w_swap : public gwidget
     int used;
 
   public:
-    virtual void draw(QPainter *p)
+    void draw(QPainter *p) override
     {
         x = x_mem->xpluswidth() + 10;
         used = procview->swap_total - procview->swap_free;
         width = drawSPECTRUM(p, x, 0, "SWAP", procview->swap_total, used);
         height = pf_char_height() + 4;
     }
-    virtual char *info()
+    char *info() override
     {
         char str[80];
 
@@ -580,7 +576,7 @@ int drawUTIME(QPainter *p, int x, int y, long boot_time)
     char buff[1024];
     // printf("size of long=%d, size of time_t=%d
     // \n",sizeof(long),sizeof(time_t));
-    long u = (long)time(NULL) - (long)boot_time;
+    long u = (long)time(nullptr) - (long)boot_time;
     int up_days = u / (3600 * 24);
     u %= (3600 * 24);
     int up_hrs = u / 3600;
@@ -603,18 +599,18 @@ int drawUTIME(QPainter *p, int x, int y, long boot_time)
 class w_utime : public gwidget
 {
   public:
-    virtual void draw(QPainter *p)
+    void draw(QPainter *p) override
     {
         height = pf_char_height() + 4;
         x = x_swap->xpluswidth() + 10;
         width = drawUTIME(p, x, 2, procview->boot_time);
     }
-    virtual const char *info() { return "passed time after system booting"; };
+    const char *info() override { return "passed time after system booting"; };
 };
 
 class w_load_avg : public gwidget
 {
-    virtual void draw(QPainter *p)
+    void draw(QPainter *p) override
     {
         char buff[64];
         // printf("w_load_avg\n");
@@ -640,13 +636,13 @@ class w_load_avg : public gwidget
         str[0] = rotate_char;
         pf_write(p, x, y, str);
     }
-    virtual const char *info()
+    const char *info() override
     {
         return "Average CPU%% each 1, 5 ,15 minutes";
     };
 };
 
-GraphBase::GraphBase(QWidget *parent, Procview *pv)
+GraphBase::GraphBase(QWidget * /*parent*/, Procview *pv)
 {
     procview = pv;
     // setCursor ( QCursor(Qt::CrossCursor) ) ;
@@ -768,7 +764,7 @@ void Infobar::paintEvent(QPaintEvent *e)
     // drww VCursor
     if (vcursor.enable)
     {
-        int px = vcursor.px;
+        /// int px = vcursor.px;
         ///	p.setPen(QColor(80,195,80));
         ///	p.drawLine (px,0,px,height());
     }
@@ -806,7 +802,6 @@ void IO_Graph::paintEvent ( QPaintEvent *e )
 QString doHistory(SysHistory *sysh)
 {
     QString str;
-    int max = 0;
 
     char buf[128];
     // sprintf(buf,"miniHistory /* %.02f%%",sysh->load_cpu*100);
@@ -834,7 +829,6 @@ QString doHistory(SysHistory *sysh)
 QString GraphBase::doHistoryTXT(SysHistory *sysh)
 {
     QString str;
-    int max = 0;
 
     char buf[128];
     // sprintf(buf,"miniHistory /* %.02f%%",sysh->load_cpu*100);
@@ -852,10 +846,8 @@ QString GraphBase::doHistoryTXT(SysHistory *sysh)
 
 void GraphBase::mouseMoveEvent(QMouseEvent *e)
 {
-    int x = 0, y = 0;
     int half_height = height() / 2;
     int dy;
-    int gap;
 
     px = e->pos().x(); // x in Infobar
     py = e->pos().y(); // y in Infobar
@@ -866,8 +858,6 @@ void GraphBase::mouseMoveEvent(QMouseEvent *e)
     // printf("px=%d py=%d  y=%d h=%d , dy=%d\n",px,py,y,height(),dy);
     // gap=infobox->width() + px  - width();
 
-    int i;
-
     // printf("procview npoints=%d  px=%d\n",npoints,px);
     QString text;
     int idx = px + history_start_idx;
@@ -902,7 +892,6 @@ void GraphBase::mouseMoveEvent(QMouseEvent *e)
 QString IO_Graph::doHistoryTXT(SysHistory *sysh)
 {
     QString str;
-    int max = 0;
 
     char buf[64], mem_str[64];
     // sprintf(buf,"miniHistory /* %.02f%%",sysh->load_cpu*100);
@@ -944,7 +933,7 @@ void IO_Graph::mouseMoveEvent ( QMouseEvent *e ) {
         GraphBase::mouseMoveEvent(e);
 } */
 
-void GraphBase::mousePressEvent(QMouseEvent *e) {}
+void GraphBase::mousePressEvent(QMouseEvent * /*e*/) {}
 
 Infobar::Infobar(QWidget *parent, Procview *pv) : QFrame(parent)
 {
@@ -986,7 +975,6 @@ Infobar::Infobar(QWidget *parent, Procview *pv) : QFrame(parent)
         QWidget::setMouseTracking(true);
     } //
 
-    int i = 0;
     // is_vertical = Qps::vertical_cpu_bar; //DEL
 
     //	cpubar=new subcpuRack(parent,pv);
@@ -1001,7 +989,7 @@ Infobar::Infobar(QWidget *parent, Procview *pv) : QFrame(parent)
 Infobar::~Infobar() { delete[] history; }
 
 // a System's Info bar
-Infobar2::Infobar2(QWidget *parent, Procview *pv)
+Infobar2::Infobar2(QWidget * /*parent*/, Procview *pv)
 {
     // procview=pv; //***
     official_height = 35;
@@ -1074,7 +1062,6 @@ void Infobar::add_history_point(unsigned int value)
 // BACKUP: add value to the history, updating peak.
 void Infobar::add_history_point2(float value)
 {
-    static float v[3] = {0, 0, 0};
     static float last_val = 0;
 
     float f;
@@ -1114,7 +1101,7 @@ QPixmap *Infobar::make_icon(int w, int h)
     QPainter pt(&icon_pm);
     pt.fillRect(0, 0, w, h, QBrush(Qt::black));
 
-    if (0)
+    if (false)
     {
         /*	int thick=h/10;
                 int bottom=h/4;
@@ -1143,10 +1130,9 @@ void Infobar::mousePressEvent(QMouseEvent *e)
 // only works if mouse cursor in this area
 void Infobar::mouseMoveEvent(QMouseEvent *e)
 {
-    int x = 0, y = 0;
     int half_height = height() / 2;
     int dy;
-    int gap;
+    // int gap;
 
     px = e->pos().x(); // x in Infobar
     py = e->pos().y(); // y in Infobar
@@ -1184,7 +1170,7 @@ void Infobar::mouseMoveEvent(QMouseEvent *e)
     if (setinfo == 0)
         infobox->setText(text);
 
-    QPoint p = mapTo(qps, e->pos()); //??
+    // QPoint p = mapTo(qps, e->pos()); //??
 
     // infobox->move(a.x()+16,a.y()+4);
     // infobox->setPos(p.x()+16,p.y()+4);
@@ -1281,7 +1267,7 @@ void Infobar::make_graph(int w, int h, QPainter *p, bool test)
     dirty = false;
 }
 
-void Infobar::resizeEvent(QResizeEvent *e)
+void Infobar::resizeEvent(QResizeEvent * /*e*/)
 {
     // static int first=0; if(first==0){	drawPixmap(); first=1;}
     drawGraphOnPixmap();
@@ -1309,18 +1295,15 @@ void subcpuRack::mousePressEvent(QMouseEvent *e)
 }
 
 // DRAFT CODE  !!!
-void subcpuRack::paintEvent(QPaintEvent *e)
+void subcpuRack::paintEvent(QPaintEvent * /*e*/)
 {
 
     // static QPaint *p=// QPainter *p=new QPainter(this);
     QPainter p(this);
-    char buff[128];
     int w;
-    int x, y;
-    int i;
     // QRect cr = contentsRect();
     // QRect cr = p->viewport();
-    QRect cr = p.window(); // rect.
+//    QRect cr = p.window(); // rect.
 
     p.fillRect(rect(), QBrush(Qt::black));
 
@@ -1329,10 +1312,8 @@ void subcpuRack::paintEvent(QPaintEvent *e)
     p.drawLine(0, 0, QWidget::width(), 0);
     // p.fillRect(cr,QBrush(QColor(255,255,255,50)));
 
-    unsigned long total = 0, user = 0, system = 0, idle = 0, nice = 0, wait = 0;
     // if(procview->num_cpus>=4) // temporaly...
     // else
-    int cpu_n = procview->num_cpus;
     w = 2 + pf_write(&p, 2, 2, "SUB CPU");
 }
 
@@ -1366,7 +1347,7 @@ Infobar2 *PDisplay::addSystem(Procview *pv)
 
     /// pv->read_system(); //
 
-    if (0 and pv->num_cpus > 9)
+    if (false and pv->num_cpus > 9)
     {
         QWidget *rack;
         rack = new subcpuRack(this, pv);
