@@ -22,17 +22,20 @@
 
 // This module implements asynchronous address->hostname lookup.
 
-#include <stdio.h>
+#include "lookup.h"
+
+#include "svec.h"
+
+#include <cstdio>
 #include <unistd.h>
 #include <fcntl.h>
 #include <sys/types.h>
 #include <sys/socket.h>
-#include <signal.h>
+#include <csignal>
 #include <netinet/in.h>
 #include <netdb.h>
 
-#include "lookup.h"
-#include "svec.cpp"
+#define fatal printf
 
 // declarations of static members
 char *Lookup::argv0;
@@ -66,7 +69,7 @@ unsigned UintQueue::dequeue()
 Hostnode::Hostnode() : next(this), prev(this) {}
 
 // create a new cache node, initialized with null string
-Hostnode::Hostnode(unsigned addr) : ipaddr(addr), next(0), prev(0) {}
+Hostnode::Hostnode(unsigned addr) : ipaddr(addr), next(nullptr), prev(nullptr) {}
 
 // must be called on the head of the list
 void Hostnode::moveToFront(Hostnode *node)
@@ -104,7 +107,7 @@ void Hostnode::insertFirst(Hostnode *node)
 Lookup::Lookup() // : hostdict(17)
 {
     sockfd = -1; // no lookup helper is running
-    readsn = writesn = 0;
+    readsn = writesn = nullptr;
     outstanding = 0;
 }
 
