@@ -32,7 +32,6 @@
 #include <QFontComboBox>
 
 //#include <qstylefactory.h>
-#include "qps.h"
 extern Qps *qps;
 
 extern QFontComboBox *font_cb;
@@ -41,7 +40,7 @@ class Swapvalid : public QValidator
 {
   public:
     Swapvalid(QWidget *parent) : QValidator(parent) {}
-    virtual State validate(QString &s, int &) const;
+    State validate(QString &s, int &) const override;
 };
 
 struct Boxvar
@@ -52,13 +51,13 @@ public:
     bool *variable;
     QCheckBox *cb;
 
-    Boxvar() : text( QString() ), variable( static_cast<  bool * >( 0 ) ), cb( static_cast< QCheckBox *>( 0 ) ) {}
+    Boxvar() : text( QString() ), variable( static_cast<  bool * >( nullptr ) ), cb( static_cast< QCheckBox *>( nullptr ) ) {}
     Boxvar( const QString t, bool *v, QCheckBox *c ) : text( t ), variable( v ), cb( c ) {}
 
     static QVector< Boxvar > *general_boxes()
     {
-        static QVector< Boxvar > boxes( { { tr( "Exit on closing" ), &Qps::flag_exit, 0}
-                                        , { tr( "Remember Position" ), &Qps::save_pos, 0}
+        static QVector< Boxvar > boxes( { { tr( "Exit on closing" ), &Qps::flag_exit, nullptr}
+                                        , { tr( "Remember Position" ), &Qps::save_pos, nullptr}
                                         } );
         return &boxes;
     }
@@ -66,22 +65,22 @@ public:
 //#ifdef LINUX
     static QVector< Boxvar > *sockinfo_boxes()
     {
-        static QVector< Boxvar > boxes( { { tr( "Host Name Lookup" ), &Qps::hostname_lookup, 0}
-                                        , { tr( "Service Name Lookup" ), &Qps::service_lookup, 0} } );
+        static QVector< Boxvar > boxes( { { tr( "Host Name Lookup" ), &Qps::hostname_lookup, nullptr}
+                                        , { tr( "Service Name Lookup" ), &Qps::service_lookup, nullptr} } );
         return &boxes;
     }
 //#endif
     static QVector< Boxvar > *tree_boxes()
     {
-        static QVector< Boxvar > boxes( { { tr( "Disclosure Triangles" ), &Qps::tree_gadgets, 0}
-                                        , { tr( "Branch Lines" ), &Qps::tree_lines, 0} } );
+        static QVector< Boxvar > boxes( { { tr( "Disclosure Triangles" ), &Qps::tree_gadgets, nullptr}
+                                        , { tr( "Branch Lines" ), &Qps::tree_lines, nullptr} } );
         return &boxes;
     }
 
     static QVector< Boxvar > *misc_boxes()
     {
-        static QVector< Boxvar > boxes( { { tr( "Auto Save Settings on Exit" ), &Qps::auto_save_options, 0}
-                                        , { tr( "Selection: Copy PIDs to Clipboard" ), &Qps::pids_to_selection, 0}
+        static QVector< Boxvar > boxes( { { tr( "Auto Save Settings on Exit" ), &Qps::auto_save_options, nullptr}
+                                        , { tr( "Selection: Copy PIDs to Clipboard" ), &Qps::pids_to_selection, nullptr}
 #ifdef SOLARIS
                                         , { tr( "Normalize NICE" ), &Qps::normalize_nice, 0}
                                         , { tr( "Use pmap for Map Names" ), &Qps::use_pmap, 0}
@@ -99,7 +98,7 @@ public:
     const QString caption;
     QVector< Boxvar > *boxvar;
 
-    Cbgroup() : caption( QString() ), boxvar( static_cast< QVector< Boxvar > * >( 0 ) ) {}
+    Cbgroup() : caption( QString() ), boxvar( static_cast< QVector< Boxvar > * >( nullptr ) ) {}
     Cbgroup( const QString c, QVector< Boxvar > *b ) : caption( c ), boxvar( b ) {}
 
     static QVector< Cbgroup > &groups()
@@ -163,8 +162,6 @@ Preferences::Preferences(QWidget *parent) : QDialog(parent)
 
     v_layout->setSpacing(1);
     // v_layout->setSpacing(1);
-    const int border_x = 10;
-    int min_x = 0;
 
     QVector< Cbgroup >::iterator endItG = Cbgroup::groups().end();
     for( QVector< Cbgroup >::iterator itG = Cbgroup::groups().begin(); itG != endItG; ++ itG )
@@ -187,7 +184,7 @@ Preferences::Preferences(QWidget *parent) : QDialog(parent)
 
     update_boxes();
 
-    rb_totalcpu = NULL; // tmp
+    rb_totalcpu = nullptr; // tmp
 
     if (QPS_PROCVIEW_CPU_NUM() > 1)
     {
@@ -217,7 +214,7 @@ Preferences::Preferences(QWidget *parent) : QDialog(parent)
     }
 
     // Appearance ====================================
-    if (font_cb == NULL)
+    if (font_cb == nullptr)
     {
         font_cb = new QFontComboBox(this); // preload
         font_cb->setWritingSystem(QFontDatabase::Latin);
@@ -350,7 +347,7 @@ void Preferences::closeEvent(QCloseEvent *event)
 }
 
 // work
-void Preferences::font_changed(int i)
+void Preferences::font_changed(int /*i*/)
 {
     int size = psizecombo->currentText().toInt();
     QFont font = font_cb->currentFont();
@@ -360,4 +357,4 @@ void Preferences::font_changed(int i)
 }
 
 // DRAFT CODE:
-void Preferences::fontset_changed(int i) {}
+void Preferences::fontset_changed(int /*i*/) {}
