@@ -45,15 +45,15 @@
 
 #include "../icon/icon.xpm"
 
-#include <stdlib.h>
-#include <stdio.h>
-#include <math.h>
+#include <cstdlib>
+#include <cstdio>
+#include <cmath>
 #include <sys/types.h>
 #include <sys/time.h>
 #include <sys/resource.h>
 #include <sys/utsname.h> // uname
-#include <signal.h>
-#include <errno.h>
+#include <csignal>
+#include <cerrno>
 #include <sched.h>
 #include <unistd.h> //for sleep
 
@@ -67,7 +67,6 @@
 #include "lookup.h"
 #include "misc.h"
 
-#ifndef USING_PCH
 #include <QBitmap>
 #include <QTimerEvent>
 #include <QVBoxLayout>
@@ -85,17 +84,23 @@
 #include <QTextEdit>
 #include <QSystemTrayIcon>
 #include <QSplitter>
-#endif
-
 #include <QDockWidget>
-#include <QSplitter>
+#include <QDialog>
+#include <QTextBrowser>
+#include <QDesktopServices>
+#include <QDialogButtonBox>
+#include <QClipboard>
+#include <QSettings>
+#include <QTextCodec>
+
+#include <iostream>
+
 /* --------------------- Global Variable START ---------------------- */
 QList<Command *> commands;
 
 bool previous_flag_show_thread_prev = false; // previous state
 bool flag_show_thread = false; // to see informations at the thread level
 int flag_thread_ok = true;     // we presume a kernel 2.6.x using NPTL
-bool flag_session_start = false;
 bool flag_start_mini = false; // Need for Xorg.Session
 bool flag_refresh = true;     // DEL
 bool flag_xcompmgr = false;   // DEL test.compiz..
@@ -106,22 +111,20 @@ bool flag_firstRun = true; // test
 
 Qps *qps;
 // ControlBar 		*controlbar=NULL;
-SearchBox *search_box = NULL;
-TFrame *infobox = NULL; // testing
-// DEL Screenshot 		*screenshot=NULL;
-QFontComboBox *font_cb = NULL;
-WatchdogDialog *watchdogDialog = NULL;
+SearchBox *search_box = nullptr;
+TFrame *infobox = nullptr; // testing
+QFontComboBox *font_cb = nullptr;
+WatchdogDialog *watchdogDialog = nullptr;
 
 /// PDisplay *pdisplay;
 
 QList<Procview *> proclist;
 
 #include "trayicon.h"
-TrayIcon *trayicon = NULL;
+TrayIcon *trayicon = nullptr;
 
 // for Non-ASCII Languages (CJK:chinese,japanese,korean, arabic ...)
-#include <QTextCodec>
-QTextCodec *codec = NULL;
+QTextCodec *codec = nullptr;
 #define UniString(str) str // codec->toUnicode(str)
 /* ------------------------ END global variables -------------------------- */
 
@@ -156,7 +159,7 @@ bool Qps::tree_lines = true;
 int Qps::swaplimit = 5; // default: warn when less than 10% swap left
 bool Qps::swaplim_percent = true;
 
-QThread *thread_main = 0;
+QThread *thread_main = nullptr;
 
 Qps::Qps()
 {
@@ -167,10 +170,10 @@ Qps::Qps()
 
     setObjectName("qps_main_window");
     timer_id = 0;
-    field_win = 0;
-    prefs_win = 0;
-    command_win = 0;
-    default_icon = 0;
+    field_win = nullptr;
+    prefs_win = nullptr;
+    command_win = nullptr;
+    default_icon = nullptr;
     default_icon_set = false;
 
     setIconSize(24, 24); // Important!!
@@ -179,8 +182,8 @@ Qps::Qps()
     if (flag_devel)
     {
         thread_main = thread(); // Test
-        printf("qps thread =%p , qApp thread =%p\n", thread(),
-               QApplication::instance()->thread());
+        std::cout << "qps thread = " << thread() << " qApp thread = "
+            << QApplication::instance()->thread() << std::endl;
     }
 
     // watchdogDialog = new WatchdogDialog; //Memory Leak
@@ -206,6 +209,8 @@ Qps::Qps()
     act = m_view->addAction( tr( "Log" ) );     // act->setData(Procview::CUSTOM);
     // m_view->hide();
 
+    QActionGroup* group = new QActionGroup (this);
+
     m_field = new QMenu("Field", this);
     act = m_field->addAction( tr( "Custom Fields" ) );
     act->setData(Procview::CUSTOM);
@@ -218,8 +223,19 @@ Qps::Qps()
 #ifdef LINUX
     act = m_field->addAction( tr( "Scheduling Fields " ) );
     act->setData(Procview::SCHED);
+    act->setActionGroup(group);
+    act->setCheckable(true);
+    act->setChecked(false);
 #endif
 
+    QList<QAction *> list = m_field->actions ();
+    for (int i = 0; i < list.size () - 1; i++)
+    {
+        QAction *act = list[i];
+        act->setCheckable(true);
+        act->setActionGroup(group);
+    }
+
     m_field->addSeparator();
     act = m_field->addAction( QIcon::fromTheme(QStringLiteral("edit-find-replace"))
                             , tr( "Select Custom Fields..." )
@@ -311,12 +327,10 @@ Qps::Qps()
     make_command_menu();                // after qpsrc reading
 
     // misc. accelerators
-    QShortcut *c1 =
-        new QShortcut(Qt::CTRL + Qt::Key_Q, this, SLOT(save_quit()));
-    QShortcut *c3 = new QShortcut(Qt::CTRL + Qt::Key_Space,
+    (void) new QShortcut(Qt::CTRL + Qt::Key_Q, this, SLOT(save_quit()));
+    (void) new QShortcut(Qt::CTRL + Qt::Key_Space,
                                   ctrlbar->pauseButton, SLOT(click()));
-    QShortcut *c2 =
-        new QShortcut(Qt::CTRL + Qt::Key_L, pstable, SLOT(repaintAll()));
+    (void) new QShortcut(Qt::CTRL + Qt::Key_L, pstable, SLOT(repaintAll()));
 
     // MOVETO : pstable better? hmmm...
     // where is leftClick?
@@ -348,9 +362,9 @@ Qps::Qps()
     /// vlayout->addSpacing(5);
 
     // if(flag_devel){
-    if (0)
+    if (false)
     {
-        if (0)
+        if (false)
         {
             QSplitter *splitter = new QSplitter(Qt::Vertical);
             QDockWidget *dock = new QDockWidget(tr("Detail"), this);
@@ -371,7 +385,7 @@ Qps::Qps()
     logbox = new QTextEdit(this);
     logbox->setReadOnly(true);
 
-    if (0) // if(flag_smallscreen==false)
+    if (false) // if(flag_smallscreen==false)
     {
         //
     }
@@ -551,7 +565,7 @@ void Qps::bar_visibility()
         statusBar->hide();
 }
 
-void Qps::timerEvent(QTimerEvent *e) { Qps::refresh(); }
+void Qps::timerEvent(QTimerEvent */*e*/) { Qps::refresh(); }
 //
 // dialogs.cpp:    qps->update_timer();
 void Qps::update_timer()
@@ -729,12 +743,12 @@ void Qps::update_menu_status()
     for (int i = 0; i < list.size() - 1; i++)
     {
         QAction *act = list[i];
-        act->setCheckable(true);
         int id = act->data().toInt();
         if (id == procview->viewfields)
+	{
             act->setChecked(true);
-        else
-            act->setChecked(false);
+	    break;
+	}
     }
 
     // Option Menu
@@ -1007,7 +1021,7 @@ void Qps::run_command(QAction *act)
         {
             if (commands[idx]->IsNeedProc() == false)
             {
-                commands[idx]->call(NULL);
+                commands[idx]->call(nullptr);
                 return;
             }
 
@@ -1217,9 +1231,9 @@ void Qps::menu_update()
     if (update_period == eternity)
         txt = "1 s";
     else if (update_period % 1000 == 0)
-        txt.sprintf("%d s", update_period / 1000);
+        txt = QString::asprintf("%d s", update_period / 1000);
     else
-        txt.sprintf("%d ms", update_period);
+        txt = QString::asprintf("%d ms", update_period);
     IntervalDialog id(txt.toUtf8().data(), update_period != eternity);
     id.exec();
     /// save_settings();
@@ -1286,7 +1300,7 @@ void Qps::menu_renice()
     // use nice of first selected process as default, and check permission
     bool possible = true;
     int euid = geteuid();
-    Procinfo *p = 0;
+    Procinfo *p = nullptr;
 
     for (int i = 0; i < procview->linear_procs.size(); i++)
     {
@@ -1319,11 +1333,6 @@ void Qps::menu_renice()
         if (ok && new_nice >= -20 && new_nice <= 19)
             break;
     }
-    int nicecol = procview->findCol(F_NICE);
-    int statcol = procview->findCol(F_STAT);
-#ifdef LINUX
-    int tmscol = procview->findCol(F_TMS);
-#endif
 
     // do the actual renicing
     for (int i = 0; i < procview->linear_procs.size(); i++)
@@ -1333,7 +1342,6 @@ void Qps::menu_renice()
         {
             if (setpriority(PRIO_PROCESS, p->pid, new_nice) < 0)
             {
-                QString s;
                 switch (errno)
                 {
                 case EPERM:
@@ -1374,7 +1382,7 @@ void Qps::menu_sched()
     }
 
     // provide reasonable defaults (first selected process)
-    Procinfo *p = 0;
+    Procinfo *p = nullptr;
     for (int i = 0; i < procview->linear_procs.size(); i++)
     {
         p = procview->linear_procs[i];
@@ -1389,11 +1397,7 @@ void Qps::menu_sched()
 
     if (sd.out_policy == SCHED_OTHER)
         sd.out_prio = 0; // only allowed value
-    int plcycol = procview->findCol(F_PLCY);
-    int rpricol = procview->findCol(F_RPRI);
-#ifdef LINUX
-    int tmscol = procview->findCol(F_TMS);
-#endif
+
     for (int i = 0; i < procview->linear_procs.size(); i++)
     {
         Procinfo *p = procview->linear_procs[i];
@@ -1551,9 +1555,8 @@ static Sflagvar flagvars[] = {{"ExitOnClose", &Qps::flag_exit},
                               {"pmap", &Qps::use_pmap}
 #endif
                               ,
-                              {0, 0}};
+                              {nullptr, nullptr}};
 
-#include <QSettings>
 extern QList<watchCond *> watchlist;
 // 1.Procview should be contstructed !
 // 2.
@@ -1597,11 +1600,14 @@ bool Qps::read_settings()
 
     // fields
     procview->cats.clear();
-    sl = set.value("field").toStringList();
-    for (int i = 0; i < sl.size(); i++)
+
+    QList<QVariant> l = set.value("field").toList();
+    for (int i = 0; i < l.size(); i++)
     {
-        QString str = sl[i];
-        procview->addField(str.toUtf8().data());
+        bool ok;
+        int id = l[i].toInt(&ok);
+        if (ok)
+            procview->addField(id);
     }
 
     if (procview->cats.isEmpty()) // happens without config file or with a corrupt one
@@ -1614,8 +1620,11 @@ bool Qps::read_settings()
         procview->viewfields = Procview::CUSTOM;
     }
 
-    int fid = procview->field_id_by_name( set.value("sort/field").toString() ); // procview->sortcat->name
-    int col = procview->findCol(fid);
+    int col = -1;
+    bool ok;
+    int fid = set.value("sort/field").toInt(&ok);
+    if (ok)
+        col = procview->findCol(fid);
     if (col < 0) // don't allow an unsorted table; sort the CPU column by default if it exists
         col = qMax(procview->findCol(F_CPU), 0);
     procview->setSortColumn(col); // Pstable::refresh()
@@ -1676,12 +1685,12 @@ void Qps::write_settings() // save setting
     set.setValue("viewproc", procview->viewproc);
 
     procview->update_customfield();
-    set.setValue("field", procview->customfields);
+    set.setValue("field", procview->customFieldIDs);
 
     if (procview->sortcat) // nullptr by default
     {
         set.beginGroup("sort");
-        set.setValue("field", procview->sortcat->name);
+        set.setValue("field", procview->sortcat->id);
         set.setValue("reversed", procview->reversed);
         set.endGroup();
     }
@@ -1740,7 +1749,7 @@ bool opt_eq(const char *arg, const char *opt)
 }
 
 // print some help to stdout and exit
-void print_help(char *cmdname)
+void print_help(char * /*cmdname*/)
 {
     fprintf(stderr, "Usage: qps [options]\n"
                     "Options:\n"
@@ -1789,8 +1798,7 @@ void Qps::clicked_trayicon(QSystemTrayIcon::ActivationReason r)
     }
 }
 
-#include <signal.h>
-void signal_handler(int sig)
+void signal_handler(int /*sig*/)
 {
     qps->save_quit();
 }
@@ -1817,31 +1825,21 @@ int main(int argc, char **argv, char **envp)
             print_help(argv[0]);
             exit(1);
         }
-        else if (opt_eq(argv[i], "session") or opt_eq(argv[i], "sm"))
-        {
-            flag_session_start = true;
-            sleep(2); // **** important !! maybe systray runs later
-        }
         else if (opt_eq(argv[i], "min")) // mini
         {
             flag_start_mini = true;
         }
-        else if (strstr(argv[i], "screen"))
-        {
-            // int screenshot_main(int argc, char **argv);
-            // screenshot_main(argc,argv);
-            // return 1;
-        }
     }
     //	codec = QTextCodec::codecForLocale(); // for Local locale
     check_system_requirement(); // check kernel version.. etc in proc.cpp
-    check_qps_running();        // check already qps running.  in misc.cpp
 
     QpsApp app(argc, argv);
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
 
-    init_misc(0); // init misc, some test code runs ...
+    init_misc(nullptr); // init misc, some test code runs ...
     qps = new Qps();
+    app.setActivationWindow(qps);
+
     //	sleep(20);
 
     QString caption( QString( "%1@%2").arg( getenv( "USER" ) )
@@ -1860,13 +1858,6 @@ int main(int argc, char **argv, char **envp)
                    , qps
                    , SLOT( hide() ) );
     menu->addSeparator();
-    if (flag_devel)
-    {
-        menu->addAction( QObject::tr( "ScreenShot" )
-                       , qps
-                       , SLOT(start_screenshot()));
-    }
-
     menu->addAction( QObject::tr( "Quit" )
                    , qps
                    , SLOT(save_quit())
@@ -1884,7 +1875,7 @@ int main(int argc, char **argv, char **envp)
 
     trayicon->sysInstall(); // ok
 
-    if (flag_session_start or flag_start_mini)
+    if (flag_start_mini)
     {
         if (trayicon->hasSysTray)
         {
@@ -1905,12 +1896,6 @@ int main(int argc, char **argv, char **envp)
     return app.exec();
 }
 
-#include <QDialog>
-#include <QTextBrowser>
-#include <QDesktopServices>
-#include <QDialogButtonBox>
-#include <QClipboard>
-
 void Qps::test_popup(const QUrl &link)
 {
 
@@ -2032,9 +2017,6 @@ void Qps::license() // -> help()
     diag->exec();
 }
 
-// slot
-void Qps::start_screenshot() {}
-
 // MOVETO qps::keyPressEvent()
 void SearchBox::keyPressEvent(QKeyEvent *e)
 {
