@@ -332,7 +332,7 @@ avsluttet med status </translation>
     <message>
         <location filename="../watchdog.ui" line="193"/>
         <source>Enable</source>
-        <translation>Aktiver</translation>
+        <translation>Skru på</translation>
     </message>
     <message>
         <location filename="../watchdog.ui" line="219"/>
@@ -529,7 +529,7 @@ avsluttet med status </translation>
     <message>
         <location filename="../listmodel.cpp" line="68"/>
         <source>Enable</source>
-        <translation>Aktiver</translation>
+        <translation>Skru på</translation>
     </message>
 </context>
 <context>
@@ -582,7 +582,7 @@ avsluttet med status </translation>
     <message>
         <location filename="../details.cpp" line="400"/>
         <source>Major,Minor device numbers (dec)</source>
-        <translation>Store,små enhetsnummer (dec)</translation>
+        <translation>Store, små enhetsnummer (dec)</translation>
     </message>
     <message>
         <location filename="../details.cpp" line="401"/>
@@ -658,7 +658,7 @@ avsluttet med status </translation>
     <message>
         <location filename="../prefs.cpp" line="249"/>
         <source>default</source>
-        <translation>forvalgt</translation>
+        <translation>standard</translation>
     </message>
     <message>
         <location filename="../prefs.cpp" line="250"/>
@@ -1751,7 +1751,7 @@ avsluttet med status </translation>
         <location filename="../misc.cpp" line="347"/>
         <source> This is unstable Alpha feature
  You maybe see a SEGFAULT...</source>
-        <translation> Dette er en ustabil funksjon i Alfa
+        <translation> Dette er en ustabil Alfa funksjon
  Du kan oppleve en SEGFAULT...</translation>
     </message>
 </context>
